@@ -1,5 +1,5 @@
 /* Maintenance of module list in libdwfl.
-   Copyright (C) 2005, 2006 Red Hat, Inc.
+   Copyright (C) 2005, 2006, 2007 Red Hat, Inc.
    This file is part of Red Hat elfutils.
 
    Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -49,6 +49,7 @@
 
 #include "libdwflP.h"
 #include <search.h>
+#include <unistd.h>
 
 static void
 free_cu (struct dwfl_cu *cu)
@@ -63,6 +64,17 @@ nofree (void *arg __attribute__ ((unused)))
 {
 }
 
+static void
+free_file (struct dwfl_file *file)
+{
+  if (file->elf != NULL)
+    {
+      elf_end (file->elf);
+      if (file->fd != -1)
+	close (file->fd);
+    }
+}
+
 void
 internal_function
 __libdwfl_module_free (Dwfl_Module *mod)
@@ -86,30 +98,37 @@ __libdwfl_module_free (Dwfl_Module *mod)
   if (mod->ebl != NULL)
     ebl_closebackend (mod->ebl);
 
-  if (mod->debug.elf != mod->main.elf && mod->debug.elf != NULL)
-    elf_end (mod->debug.elf);
-  if (mod->main.elf != NULL)
-    elf_end (mod->main.elf);
+  if (mod->debug.elf != mod->main.elf)
+    free_file (&mod->debug);
+  free_file (&mod->main);
 
   free (mod->name);
+  free (mod);
 }
 
 void
-dwfl_report_begin (Dwfl *dwfl)
+dwfl_report_begin_add (Dwfl *dwfl)
 {
-  for (Dwfl_Module *m = dwfl->modulelist; m != NULL; m = m->next)
-    m->gc = true;
-
   if (dwfl->modules != NULL)
     free (dwfl->modules);
   dwfl->modules = NULL;
   dwfl->nmodules = 0;
+}
+INTDEF (dwfl_report_begin_add)
+
+void
+dwfl_report_begin (Dwfl *dwfl)
+{
+  INTUSE(dwfl_report_begin_add) (dwfl);
+
+  for (Dwfl_Module *m = dwfl->modulelist; m != NULL; m = m->next)
+    m->gc = true;
 
   dwfl->offline_next_address = OFFLINE_REDZONE;
 }
 INTDEF (dwfl_report_begin)
 
-/* Report that a module called NAME pans addresses [START, END).
+/* Report that a module called NAME spans addresses [START, END).
    Returns the module handle, either existing or newly allocated,
    or returns a null pointer for an allocation error.  */
 Dwfl_Module *
@@ -172,10 +191,11 @@ compare_modules (const void *a, const void *b)
   if (m2 == NULL)
     return 1;
 
-  GElf_Sxword diff = m1->low_addr - m2->low_addr;
-  if (diff < 0)
+  /* No signed difference calculation is correct here, since the
+     terms are unsigned and could be more than INT64_MAX apart.  */
+  if (m1->low_addr < m2->low_addr)
     return -1;
-  if (diff > 0)
+  if (m1->low_addr > m2->low_addr)
     return 1;
   return 0;
 }
