@@ -1,5 +1,5 @@
 /* Interfaces for libdwfl.
-   Copyright (C) 2005, 2006 Red Hat, Inc.
+   Copyright (C) 2005, 2006, 2007 Red Hat, Inc.
    This file is part of Red Hat elfutils.
 
    Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -76,7 +76,8 @@ typedef struct
 			 char **debuginfo_file_name);
 
   /* Fill *ADDR with the loaded address of the section called SECNAME in
-     the given module.  This is called exactly once for each SHF_ALLOC
+     the given module.  Use (Dwarf_Addr) -1 if this section is omitted from
+     accessible memory.  This is called exactly once for each SHF_ALLOC
      section that relocations affecting DWARF data refer to, so it can
      easily be used to collect state about the sections referenced.  */
   int (*section_address) (Dwfl_Module *mod, void **userdata,
@@ -94,7 +95,9 @@ extern "C" {
 #endif
 
 /* Start a new session with the library.  */
-extern Dwfl *dwfl_begin (const Dwfl_Callbacks *callbacks);
+extern Dwfl *dwfl_begin (const Dwfl_Callbacks *callbacks)
+  __nonnull_attribute__ (1);
+
 
 /* End a session.  */
 extern void dwfl_end (Dwfl *);
@@ -153,6 +156,14 @@ extern int dwfl_report_end (Dwfl *dwfl,
 					    void *arg),
 			    void *arg);
 
+/* Start reporting additional modules to the library.  No calls but
+   dwfl_report_* can be made on DWFL until dwfl_report_end is called.
+   This is like dwfl_report_begin, but all the old modules are kept on.
+   More dwfl_report_* calls can follow to add more modules.
+   When dwfl_report_end is called, no old modules will be removed.  */
+extern void dwfl_report_begin_add (Dwfl *dwfl);
+
+
 /* Return the name of the module, and for each non-null argument store
    interesting details: *USERDATA is a location for storing your own
    pointer, **USERDATA is initially null; *START and *END give the address
@@ -329,6 +340,21 @@ extern const char *dwfl_module_getsym (Dwfl_Module *mod, int ndx,
 /* Find the symbol that ADDRESS lies inside, and return its name.  */
 extern const char *dwfl_module_addrname (Dwfl_Module *mod, GElf_Addr address);
 
+/* Find the symbol that ADDRESS lies inside, and return detailed
+   information as for dwfl_module_getsym (above).  */
+extern const char *dwfl_module_addrsym (Dwfl_Module *mod, GElf_Addr address,
+					GElf_Sym *sym, GElf_Word *shndxp)
+  __nonnull_attribute__ (3);
+
+/* Find the ELF section that *ADDRESS lies inside and return it.
+   On success, adjusts *ADDRESS to be relative to the section,
+   and sets *BIAS to the difference between addresses used in
+   the returned section's headers and run-time addresses.  */
+extern Elf_Scn *dwfl_module_address_section (Dwfl_Module *mod,
+					     Dwarf_Addr *address,
+					     Dwarf_Addr *bias)
+  __nonnull_attribute__ (2, 3);
+
 
 /*** Dwarf access functions ***/
 
@@ -426,7 +452,8 @@ extern int dwfl_module_register_names (Dwfl_Module *mod,
 							int regno,
 							const char *setname,
 							const char *prefix,
-							const char *regname),
+							const char *regname,
+							int bits, int type),
 				       void *arg);
 
 
