@@ -1,5 +1,5 @@
 /* Standard libdwfl callbacks for debugging the running Linux kernel.
-   Copyright (C) 2005, 2006 Red Hat, Inc.
+   Copyright (C) 2005, 2006, 2007 Red Hat, Inc.
    This file is part of Red Hat elfutils.
 
    Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -63,8 +63,11 @@
 #include <fts.h>
 
 
+#define KERNEL_MODNAME	"kernel"
+
 #define MODULEDIRFMT	"/lib/modules/%s"
 
+#define KSYMSFILE	"/proc/kallsyms"
 #define MODULELIST	"/proc/modules"
 #define	SECADDRDIRFMT	"/sys/module/%s/sections/"
 #define MODULE_SECT_NAME_LEN 32	/* Minimum any linux/module.h has had.  */
@@ -115,6 +118,26 @@ kernel_release (void)
   return utsname.release;
 }
 
+static int
+find_kernel_elf (Dwfl *dwfl, const char *release, char **fname)
+{
+  if ((release[0] == '/'
+       ? asprintf (fname, "%s/vmlinux", release)
+       : asprintf (fname, "/boot/vmlinux-%s", release)) < 0)
+    return -1;
+
+  int fd = try_kernel_name (dwfl, fname);
+  if (fd < 0 && release[0] != '/')
+    {
+      free (*fname);
+      if (asprintf (fname, MODULEDIRFMT "/vmlinux", release) < 0)
+	return -1;
+      fd = try_kernel_name (dwfl, fname);
+    }
+
+  return fd;
+}
+
 static int
 report_kernel (Dwfl *dwfl, const char *release,
 	       int (*predicate) (const char *module, const char *file))
@@ -122,23 +145,19 @@ report_kernel (Dwfl *dwfl, const char *release,
   if (dwfl == NULL)
     return -1;
 
-  char *fname = NULL;
-  if (release[0] == '/')
-    asprintf (&fname, "%s/vmlinux", release);
-  else
-    asprintf (&fname, "/boot/vmlinux-%s", release);
-  int fd = try_kernel_name (dwfl, &fname);
-  if (fd < 0 && release[0] != '/')
+  if (release == NULL)
     {
-      free (fname);
-      fname = NULL;
-      asprintf (&fname, MODULEDIRFMT "/vmlinux", release);
-      fd = try_kernel_name (dwfl, &fname);
+      release = kernel_release ();
+      if (release == NULL)
+	return errno;
     }
 
+  char *fname;
+  int fd = find_kernel_elf (dwfl, release, &fname);
+
   int result = 0;
   if (fd < 0)
-    result = ((predicate != NULL && !(*predicate) ("kernel", NULL))
+    result = ((predicate != NULL && !(*predicate) (KERNEL_MODNAME, NULL))
 	      ? 0 : errno ?: ENOENT);
   else
     {
@@ -147,14 +166,15 @@ report_kernel (Dwfl *dwfl, const char *release,
       if (predicate != NULL)
 	{
 	  /* Let the predicate decide whether to use this one.  */
-	  int want = (*predicate) ("kernel", fname);
+	  int want = (*predicate) (KERNEL_MODNAME, fname);
 	  if (want < 0)
 	    result = errno;
 	  report = want > 0;
 	}
 
       if (report
-	  && INTUSE(dwfl_report_elf) (dwfl, "kernel", fname, fd, 0) == NULL)
+	  && INTUSE(dwfl_report_elf) (dwfl, KERNEL_MODNAME,
+				      fname, fd, 0) == NULL)
 	{
 	  close (fd);
 	  result = -1;
@@ -177,13 +197,6 @@ dwfl_linux_kernel_report_offline (Dwfl *dwfl, const char *release,
 				  int (*predicate) (const char *module,
 						    const char *file))
 {
-  if (release == NULL)
-    {
-      release = kernel_release ();
-      if (release == NULL)
-	return errno;
-    }
-
   /* First report the kernel.  */
   int result = report_kernel (dwfl, release, predicate);
   if (result == 0)
@@ -195,8 +208,7 @@ dwfl_linux_kernel_report_offline (Dwfl *dwfl, const char *release,
 	modulesdir[0] = (char *) release;
       else
 	{
-	  asprintf (&modulesdir[0], MODULEDIRFMT "/kernel", release);
-	  if (modulesdir[0] == NULL)
+	  if (asprintf (&modulesdir[0], MODULEDIRFMT "/kernel", release) < 0)
 	    return errno;
 	}
 
@@ -280,15 +292,87 @@ dwfl_linux_kernel_report_offline (Dwfl *dwfl, const char *release,
 INTDEF (dwfl_linux_kernel_report_offline)
 
 
-/* Find the ELF file for the running kernel and dwfl_report_elf it.  */
+/* Grovel around to guess the bounds of the runtime kernel image.  */
+static int
+intuit_kernel_bounds (Dwarf_Addr *start, Dwarf_Addr *end)
+{
+  FILE *f = fopen (KSYMSFILE, "r");
+  if (f == NULL)
+    return errno;
+
+  (void) __fsetlocking (f, FSETLOCKING_BYCALLER);
+
+  char *line = NULL;
+  size_t linesz = 0;
+  size_t n = getline (&line, &linesz, f);
+  Dwarf_Addr first;
+  char *p = NULL;
+  int result = 0;
+  if (n > 0 && (first = strtoull (line, &p, 16)) > 0 && p > line)
+    {
+      Dwarf_Addr last = 0;
+      while ((n = getline (&line, &linesz, f)) > 1 && line[n - 2] != ']')
+	{
+	  p = NULL;
+	  last = strtoull (line, &p, 16);
+	  if (p == NULL || p == line || last == 0)
+	    {
+	      result = -1;
+	      break;
+	    }
+	}
+      if ((n == 0 && feof_unlocked (f)) || (n > 1 && line[n - 2] == ']'))
+	{
+	  Dwarf_Addr round_kernel = sysconf (_SC_PAGE_SIZE);
+	  first &= -(Dwarf_Addr) round_kernel;
+	  last += round_kernel - 1;
+	  last &= -(Dwarf_Addr) round_kernel;
+	  *start = first;
+	  *end = last;
+	  result = 0;
+	}
+    }
+  free (line);
+
+  if (result == -1)
+    result = ferror_unlocked (f) ? errno : ENOEXEC;
+
+  fclose (f);
+
+  return result;
+}
+
 int
 dwfl_linux_kernel_report_kernel (Dwfl *dwfl)
 {
-  const char *release = kernel_release ();
-  if (release == NULL)
-    return errno;
+  Dwarf_Addr start;
+  Dwarf_Addr end;
+  inline int report (void)
+    {
+      return INTUSE(dwfl_report_module) (dwfl, KERNEL_MODNAME,
+					 start, end) == NULL ? -1 : 0;
+    }
 
-  return report_kernel (dwfl, release, NULL);
+  /* This is a bit of a kludge.  If we already reported the kernel,
+     don't bother figuring it out again--it never changes.  */
+  for (Dwfl_Module *m = dwfl->modulelist; m != NULL; m = m->next)
+    if (!strcmp (m->name, KERNEL_MODNAME))
+      {
+	start = m->low_addr;
+	end = m->high_addr;
+	return report ();
+      }
+
+  /* Try to figure out the bounds of the kernel image without
+     looking for any vmlinux file.  */
+  int result = intuit_kernel_bounds (&start, &end);
+  if (result == 0)
+    return report ();
+  if (result != ENOENT)
+    return result;
+
+  /* Find the ELF file for the running kernel and dwfl_report_elf it.  */
+  return report_kernel (dwfl, NULL, NULL);
 }
 INTDEF (dwfl_linux_kernel_report_kernel)
 
@@ -307,11 +391,13 @@ dwfl_linux_kernel_find_elf (Dwfl_Module *mod __attribute__ ((unused)),
   if (release == NULL)
     return errno;
 
+  if (!strcmp (module_name, KERNEL_MODNAME))
+    return find_kernel_elf (mod->dwfl, release, file_name);
+
   /* Do "find /lib/modules/`uname -r`/kernel -name MODULE_NAME.ko".  */
 
   char *modulesdir[] = { NULL, NULL };
-  asprintf (&modulesdir[0], MODULEDIRFMT "/kernel", release);
-  if (modulesdir[0] == NULL)
+  if (asprintf (&modulesdir[0], MODULEDIRFMT "/kernel", release) < 0)
     return -1;
 
   FTS *fts = fts_open (modulesdir, FTS_LOGICAL | FTS_NOSTAT, NULL);
@@ -417,9 +503,8 @@ dwfl_linux_kernel_module_section_address
  const GElf_Shdr *shdr __attribute__ ((unused)),
  Dwarf_Addr *addr)
 {
-  char *sysfile = NULL;
-  asprintf (&sysfile, SECADDRDIRFMT "%s", modname, secname);
-  if (sysfile == NULL)
+  char *sysfile;
+  if (asprintf (&sysfile, SECADDRDIRFMT "%s", modname, secname) < 0)
     return ENOMEM;
 
   FILE *f = fopen (sysfile, "r");
@@ -434,14 +519,14 @@ dwfl_linux_kernel_module_section_address
 	     CONFIG_MODULE_UNLOAD, the .exit.* sections are not
 	     actually loaded at all.
 
-	     Just relocate these bogusly to zero.  This part of the
-	     debug information will not be of any use.  */
+	     Setting *ADDR to -1 tells the caller this section is
+	     actually absent from memory.  */
 
 	  if (!strcmp (secname, ".modinfo")
 	      || !strcmp (secname, ".data.percpu")
 	      || !strncmp (secname, ".exit", 5))
 	    {
-	      *addr = 0;
+	      *addr = (Dwarf_Addr) -1l;
 	      return DWARF_CB_OK;
 	    }
 
@@ -453,9 +538,8 @@ dwfl_linux_kernel_module_section_address
 	  const bool is_init = !strncmp (secname, ".init", 5);
 	  if (is_init)
 	    {
-	      sysfile = NULL;
-	      asprintf (&sysfile, SECADDRDIRFMT "_%s", modname, &secname[1]);
-	      if (sysfile == NULL)
+	      if (asprintf (&sysfile, SECADDRDIRFMT "_%s",
+			    modname, &secname[1]) < 0)
 		return ENOMEM;
 	      f = fopen (sysfile, "r");
 	      free (sysfile);
@@ -469,10 +553,9 @@ dwfl_linux_kernel_module_section_address
 	  size_t namelen = strlen (secname);
 	  if (namelen >= MODULE_SECT_NAME_LEN)
 	    {
-	      sysfile = NULL;
 	      int len = asprintf (&sysfile, SECADDRDIRFMT "%s",
 				  modname, secname);
-	      if (sysfile == NULL)
+	      if (len < 0)
 		return ENOMEM;
 	      char *end = sysfile + len;
 	      do
