@@ -1,5 +1,5 @@
 /* Generate ELF backend handle.
-   Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Red Hat, Inc.
+   Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Red Hat, Inc.
    This file is part of Red Hat elfutils.
 
    Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -55,6 +55,7 @@
 #include <dlfcn.h>
 #include <error.h>
 #include <libelfP.h>
+#include <dwarf.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -170,6 +171,7 @@ static const char *default_section_name (int ignore, int ignore2, char *buf,
 					 size_t len);
 static const char *default_machine_flag_name (Elf64_Word *ignore);
 static bool default_machine_flag_check (Elf64_Word flags);
+static bool default_machine_section_flag_check (GElf_Xword flags);
 static const char *default_symbol_type_name (int ignore, char *buf,
 					     size_t len);
 static const char *default_symbol_binding_name (int ignore, char *buf,
@@ -199,10 +201,11 @@ static bool default_check_special_symbol (Elf *elf, GElf_Ehdr *ehdr,
 static bool default_bss_plt_p (Elf *elf, GElf_Ehdr *ehdr);
 static int default_return_value_location (Dwarf_Die *functypedie,
 					  const Dwarf_Op **locops);
-static ssize_t default_register_name (Ebl *ebl,
+static ssize_t default_register_info (Ebl *ebl,
 				      int regno, char *name, size_t namelen,
 				      const char **prefix,
-				      const char **setname);
+				      const char **setname,
+				      int *bits, int *type);
 
 
 static void
@@ -219,6 +222,7 @@ fill_defaults (Ebl *result)
   result->section_name = default_section_name;
   result->machine_flag_name = default_machine_flag_name;
   result->machine_flag_check = default_machine_flag_check;
+  result->machine_section_flag_check = default_machine_section_flag_check;
   result->symbol_type_name = default_symbol_type_name;
   result->symbol_binding_name = default_symbol_binding_name;
   result->dynamic_tag_name = default_dynamic_tag_name;
@@ -236,7 +240,7 @@ fill_defaults (Ebl *result)
   result->check_special_symbol = default_check_special_symbol;
   result->bss_plt_p = default_bss_plt_p;
   result->return_value_location = default_return_value_location;
-  result->register_name = default_register_name;
+  result->register_info = default_register_info;
   result->destr = default_destr;
   result->sysvhash_entrysize = sizeof (Elf32_Word);
 }
@@ -500,6 +504,12 @@ default_machine_flag_check (Elf64_Word flags __attribute__ ((unused)))
   return flags == 0;
 }
 
+static bool
+default_machine_section_flag_check (GElf_Xword flags)
+{
+  return flags == 0;
+}
+
 static const char *
 default_symbol_type_name (int ignore __attribute__ ((unused)),
 			  char *buf __attribute__ ((unused)),
@@ -657,15 +667,18 @@ default_return_value_location (Dwarf_Die *functypedie __attribute__ ((unused)),
 }
 
 static ssize_t
-default_register_name (Ebl *ebl __attribute__ ((unused)),
+default_register_info (Ebl *ebl __attribute__ ((unused)),
 		       int regno, char *name, size_t namelen,
 		       const char **prefix,
-		       const char **setname)
+		       const char **setname,
+		       int *bits, int *type)
 {
   if (name == NULL)
     return 0;
 
   *setname = "???";
   *prefix = "";
+  *bits = -1;
+  *type = DW_ATE_void;
   return snprintf (name, namelen, "reg%d", regno);
 }
