@@ -1,5 +1,5 @@
 /* Interface for libebl.
-   Copyright (C) 2000, 2001, 2002, 2004, 2005, 2006 Red Hat, Inc.
+   Copyright (C) 2000, 2001, 2002, 2004, 2005, 2006, 2007 Red Hat, Inc.
    This file is part of Red Hat elfutils.
 
    Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -138,6 +138,9 @@ extern const char *ebl_machine_flag_name (Ebl *ebl, GElf_Word flags,
 /* Check whether machine flag is valid.  */
 extern bool ebl_machine_flag_check (Ebl *ebl, GElf_Word flags);
 
+/* Check whether SHF_MASKPROC flags are valid.  */
+extern bool ebl_machine_section_flag_check (Ebl *ebl, GElf_Xword flags);
+
 /* Return symbol type name.  */
 extern const char *ebl_symbol_type_name (Ebl *ebl, int symbol,
 					 char *buf, size_t len);
@@ -219,7 +222,7 @@ extern int ebl_return_value_location (Ebl *ebl,
 				      Dwarf_Die *functypedie,
 				      const Dwarf_Op **locops);
 
-/* Fill in register name information given DWARF register numbers.
+/* Fill in register information given DWARF register numbers.
    If NAME is null, return the maximum REGNO + 1 that has a name.
    Otherwise, store in NAME the name for DWARF register number REGNO
    and return the number of bytes written (including '\0' terminator).
@@ -229,9 +232,10 @@ extern int ebl_return_value_location (Ebl *ebl,
    fit for "%s registers" title display, and *PREFIX to the string
    that precedes NAME in canonical assembler syntax (e.g. "%" or "$").
    The NAME string contains identifier characters only (maybe just digits).  */
-extern ssize_t ebl_register_name (Ebl *ebl,
+extern ssize_t ebl_register_info (Ebl *ebl,
 				  int regno, char *name, size_t namelen,
-				  const char **prefix, const char **setname);
+				  const char **prefix, const char **setname,
+				  int *bits, int *type);
 
 
 /* ELF string table handling.  */
