@@ -1,5 +1,5 @@
 /* Create descriptor for processing file.
-   Copyright (C) 1998-2005, 2006 Red Hat, Inc.
+   Copyright (C) 1998-2005, 2006, 2007 Red Hat, Inc.
    This file is part of Red Hat elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 1998.
 
@@ -155,9 +155,9 @@ get_shnum (void *map_address, unsigned char *e_ident, int fildes, off_t offset,
 
       if (unlikely (result == 0) && ehdr.e32->e_shoff != 0)
 	{
-	  if (offset + ehdr.e32->e_shoff + sizeof (Elf32_Shdr) > maxsize)
+	  if (ehdr.e32->e_shoff + sizeof (Elf32_Shdr) > maxsize)
 	    /* Cannot read the first section header.  */
-	    return (size_t) -1l;
+	    return 0;
 
 	  if (likely (map_address != NULL) && e_ident[EI_DATA] == MY_ELFDATA
 	      && (ALLOW_UNALIGNED
@@ -190,6 +190,11 @@ get_shnum (void *map_address, unsigned char *e_ident, int fildes, off_t offset,
 	      result = size;
 	    }
 	}
+
+      /* If the section headers were truncated, pretend none were there.  */
+      if (ehdr.e32->e_shoff > maxsize
+	  || maxsize - ehdr.e32->e_shoff < sizeof (Elf32_Shdr) * result)
+	result = 0;
     }
   else
     {
@@ -198,9 +203,9 @@ get_shnum (void *map_address, unsigned char *e_ident, int fildes, off_t offset,
 
       if (unlikely (result == 0) && ehdr.e64->e_shoff != 0)
 	{
-	  if (offset + ehdr.e64->e_shoff + sizeof (Elf64_Shdr) > maxsize)
+	  if (ehdr.e64->e_shoff + sizeof (Elf64_Shdr) > maxsize)
 	    /* Cannot read the first section header.  */
-	    return (size_t) -1l;
+	    return 0;
 
 	  Elf64_Xword size;
 	  if (likely (map_address != NULL) && e_ident[EI_DATA] == MY_ELFDATA
@@ -236,6 +241,11 @@ get_shnum (void *map_address, unsigned char *e_ident, int fildes, off_t offset,
 
 	  result = size;
 	}
+
+      /* If the section headers were truncated, pretend none were there.  */
+      if (ehdr.e64->e_shoff > maxsize
+	  || maxsize - ehdr.e64->e_shoff < sizeof (Elf64_Shdr) * result)
+	result = 0;
     }
 
   return result;
@@ -561,6 +571,7 @@ read_file (int fildes, off_t offset, size_t maxsize,
 					      ? PROT_READ
 					      : PROT_READ|PROT_WRITE),
 			      cmd == ELF_C_READ_MMAP_PRIVATE
+			      || cmd == ELF_C_READ_MMAP
 			      ? MAP_PRIVATE : MAP_SHARED,
 			      fildes, offset);
 
@@ -686,7 +697,7 @@ read_long_names (Elf *elf)
 	  /* NUL-terminate the string.  */
 	  *runp = '\0';
 
-	  /* Skip the NUL bzte and the \012.  */
+	  /* Skip the NUL byte and the \012.  */
 	  runp += 2;
 
 	  /* A sanity check.  Somebody might have generated invalid
