@@ -1,15 +1,27 @@
-/* Copyright (C) 2001, 2002, 2003, 2005 Red Hat, Inc.
+/* Copyright (C) 2001, 2002, 2003, 2005, 2006 Red Hat, Inc.
+   This file is part of Red Hat elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 2001.
 
-   This program is Open Source software; you can redistribute it and/or
-   modify it under the terms of the Open Software License version 1.0 as
-   published by the Open Source Initiative.
+   Red Hat elfutils is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by the
+   Free Software Foundation; version 2 of the License.
 
-   You should have received a copy of the Open Software License along
-   with this program; if not, you may obtain a copy of the Open Software
-   License version 1.0 from http://www.opensource.org/licenses/osl.php or
-   by writing the Open Source Initiative c/o Lawrence Rosen, Esq.,
-   3001 King Ranch Road, Ukiah, CA 95482.   */
+   Red Hat elfutils is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with Red Hat elfutils; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301 USA.
+
+   Red Hat elfutils is an included package of the Open Invention Network.
+   An included package of the Open Invention Network is a package for which
+   Open Invention Network licensees cross-license their patents.  No patent
+   license is granted, either expressly or impliedly, by designation as an
+   included package.  Should you wish to participate in the Open Invention
+   Network licensing program, please visit www.openinventionnetwork.com
+   <http://www.openinventionnetwork.com>.  */
 
 #ifndef LD_H
 #define LD_H	1
@@ -103,6 +115,10 @@ struct usedfiles
      used in a reference.  */
   bool used;
 
+  /* True when file should be added to DT_NEEDED list only when
+     directly referenced.  */
+  bool as_needed;
+
   /* If nonzero this is the archive sequence number which can be used to
      determine whether back refernces from -( -) or GROUP statements
      have to be followed.  */
@@ -158,6 +174,8 @@ struct usedfiles
     Elf32_Word allsectionsidx;
     /* True if the section is used.  */
     bool used;
+    /* True if section is an unused COMDAT section.  */
+    bool unused_comdat;
     /* Section group number.  This is the index of the SHT_GROUP section.  */
     Elf32_Word grpid;
     /* Pointer back to the containing file information structure.  */
@@ -428,6 +446,8 @@ struct symbol
   unsigned int weak:1;
   unsigned int added:1;
   unsigned int merged:1;
+  unsigned int local:1;
+  unsigned int hidden:1;
   /* Nonzero if the symbol is on the from_dso list.  */
   unsigned int on_dsolist:1;
   /* Nonzero if symbol needs copy relocation, reset when the
@@ -779,6 +799,10 @@ struct ld_state
   /* If true static linking is requested.  */
   bool statically;
 
+  /* If true, add DT_NEEDED entries for following files if they are
+     needed.  */
+  bool as_needed;
+
   /* How to extract elements from archives.  */
   enum extract_rule extract_rule;
 
@@ -936,6 +960,14 @@ struct ld_state
   bool default_bind_local;
   bool default_bind_global;
 
+  /* Execuatable stack selection.  */
+  enum execstack
+    {
+      execstack_false = 0,
+      execstack_true,
+      execstack_false_force
+    } execstack;
+
   /* True if only used sections are used.  */
   bool gc_sections;
 
@@ -979,9 +1011,8 @@ struct ld_state
   /* Lazy-loading state for dependencies.  */
   bool lazyload;
 
-  /* True is DSOs which are not used in the linking process are not
-     recorded.  */
-  bool ignore_unused_dsos;
+  /* True if an .eh_frame_hdr section should be generated.  */
+  bool eh_frame_hdr;
 
 
   /* True if in executables all global symbols should be exported in
