@@ -91,7 +91,7 @@
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 71 "/home/drepper/devel/elfutils/src/ldscript.y"
+#line 71 "../../../redhat/stock-elfutils/src/ldscript.y"
 typedef union YYSTYPE {
   uintmax_t num;
   enum expression_tag op;
